/*
 * Copyright (c) 2012, Stephen Chin
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL STEPHEN CHIN OR ORACLE CORPORATION BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package comsysto.server;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RequestMapping("/crm/")
@Controller
public class CustomerApiController {

    @Autowired
    @Qualifier("neo4jCustomerService")
    //@Qualifier("customerService")
    private ICustomerService customerService;

    @ResponseBody
    @RequestMapping(value = "/customer/{id}", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    public ICustomer customerById(@PathVariable("id") Integer id) {
        System.out.println("/customer/"+id);
        return this.customerService.getCustomerById(id);
    }

    @ResponseBody
    @RequestMapping(value = "/customers", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    public List<ICustomer> customers() {
        System.out.println("/customers");
        return this.customerService.getAllCustomers();
    }

    @ResponseBody
    @RequestMapping(value = "/customers", method = RequestMethod.POST)
    public Integer addCustomer(@Valid @RequestBody Customer customer) {
        System.out.println("//customers/ ->addCustomer: "+customer.getFirstName()+" "+customer.getLastName());
        ICustomer newCustomer = customerService.createCustomer(customer.getFirstName(), customer.getLastName(), customer.getSignupDate());
        return newCustomer.getId();
    }

    @ResponseBody
    @RequestMapping(value = "/customer/{id}", method = RequestMethod.POST)
    public Integer updateCustomer(@PathVariable("id") Integer id, @RequestBody Customer customer) {
        System.out.println("//customers/ ->updateCustomer: "+customer.getFirstName()+" "+customer.getLastName());
        customerService.updateCustomer(id, customer.getFirstName(), customer.getLastName(), customer.getSignupDate());
        return id;
    }

    @ResponseBody
    @RequestMapping(value = "/customer/{id}", method = RequestMethod.DELETE)
    public void deleteCustomer(@PathVariable("id") Integer id) {
        System.out.println("/customer/"+id+" ->delete");
        customerService.deleteCustomer(id);
    }

}             
